@@ -10,7 +10,6 @@ from . import (  # noqa: F401
     canary_modules,
     checks,
     command_line_helpers,
-    commands_configuration_file,
     configuration_file,
     configuration_parser,
     documentation,
@@ -32,7 +31,6 @@ from . import (  # noqa: F401
     resource_manager,
     rest_map_configuration_file,
     saved_searches_configuration_file,
-    transforms_configuration_file,
     validation_report,
     validator,
     version,
