@@ -16,6 +16,7 @@ from io import BytesIO
 from splunk_appinspect.checks import Check
 from splunk_appinspect.configuration_parser import InvalidSectionError
 from splunk_appinspect.python_modules_metadata import python_modules_metadata_store
+from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
 
 from . import (
     alert_actions,
@@ -28,7 +29,6 @@ from . import (
     configuration_parser,
     custom_commands,
     custom_visualizations,
-    distsearch_configuration_file,
     file_resource,
     file_view,
     indexes_configuration_file,
@@ -42,9 +42,7 @@ from . import (
     rest_map,
     saved_searches,
     telemetry_configuration_file,
-    transforms_configuration_file,
     web_configuration_file,
-    workflow_actions,
 )
 
 # Third Party Libraries
@@ -151,6 +149,8 @@ class App(object):
         self.app_conf_files = {}
         # Invalid conf files cache
         self.invalid_conf_files = {}
+        # Custom conf files cache
+        self._custom_conf_files = None
         if not platform.system() == "Windows":
             for directory, file, _ in self.iterate_files():
                 current_file_relative_path = os.path.join(directory, file)
@@ -602,6 +602,7 @@ class App(object):
         basedir="",
         excluded_dirs=None,
         types=None,
+        names=None,
         excluded_types=None,
         excluded_bases=None,
         recurse_depth=float("inf"),
@@ -637,10 +638,12 @@ class App(object):
         """
         excluded_dirs = excluded_dirs or []
         types = types or []
+        names = names or []
         excluded_types = excluded_types or []
         excluded_bases = excluded_bases or []
         excluded_bases = [base.lower() for base in excluded_bases]
         check_extensions = len(types) > 0
+        check_names = len(names) > 0
 
         if not isinstance(basedir, list):
             basedir = [basedir]
@@ -666,10 +669,11 @@ class App(object):
                 # Create the file's relative path from within the app
                 dir_in_app = base.replace(self.app_dir + os.path.sep, "")
                 if current_depth <= recurse_depth:
-                    for file in files:
-                        filebase, ext = os.path.splitext(file)
+                    for file_name in files:
+                        filebase, ext = os.path.splitext(file_name)
                         if (
                             (check_extensions and ext not in types)
+                            or (check_names and file_name not in names)
                             or (ext != "" and ext in excluded_types)
                             or (filebase.lower() in excluded_bases)
                         ):
@@ -693,9 +697,9 @@ class App(object):
                                 current_frame = current_frame.f_back
 
                             if not self._filter_by_trusted_libs(
-                                dir_in_app, file, check_name
+                                dir_in_app, file_name, check_name
                             ):
-                                yield (dir_in_app, file, ext)
+                                yield (dir_in_app, file_name, ext)
                 else:
                     pass
 
@@ -815,8 +819,10 @@ class App(object):
         basedir="",
         excluded_dirs=None,
         types=None,
+        names=None,
         excluded_types=None,
         excluded_bases=None,
+        recurse_depth=float("inf"),
     ):
         """Takes a list of patterns and iterates through all files, running
         each of the patterns on each line of each of those files.
@@ -826,6 +832,7 @@ class App(object):
         """
         excluded_dirs = excluded_dirs or []
         types = types or []
+        names = names or []
         excluded_types = excluded_types or []
         excluded_bases = excluded_bases or []
         matches = []
@@ -835,19 +842,21 @@ class App(object):
         files_iterator = self.iterate_files(
             basedir=basedir,
             excluded_dirs=excluded_dirs,
+            names=names,
             types=types,
             excluded_types=all_excluded_types,
             excluded_bases=excluded_bases,
+            recurse_depth=recurse_depth,
         )
-        for dir, filename, ext in files_iterator:
-            relative_filepath = os.path.join(dir, filename)
+        for (dir_in_app, file_name, _) in files_iterator:
+            relative_filepath = os.path.join(dir_in_app, file_name)
             file_to_inspect = inspected_file.InspectedFile.factory(
-                os.path.join(self.app_dir, dir, filename)
+                self.get_filename(dir_in_app, file_name)
             )
             found_matches = file_to_inspect.search_for_patterns(patterns)
             matches_with_relative_path = []
             for (fileref_output, file_match) in found_matches:
-                filepath, line_number = fileref_output.rsplit(":", 1)
+                _, line_number = fileref_output.rsplit(":", 1)
                 relative_file_ref_output = f"{relative_filepath}:{line_number}"
                 matches_with_relative_path.append(
                     (relative_file_ref_output, file_match)
@@ -862,23 +871,28 @@ class App(object):
         basedir="",
         excluded_dirs=None,
         types=None,
+        names=None,
         excluded_types=None,
         excluded_bases=None,
+        recurse_depth=float("inf"),
     ):
         """Takes a pattern and iterates over matching files, testing each line.
         Same as search_for_patterns, but with a single pattern.
         """
         excluded_dirs = excluded_dirs or []
         types = types or []
+        names = names or []
         excluded_types = excluded_types or []
         excluded_bases = excluded_bases or []
         return self.search_for_patterns(
             [pattern],
             basedir=basedir,
             excluded_dirs=excluded_dirs,
+            names=names,
             types=types,
             excluded_types=excluded_types,
             excluded_bases=excluded_bases,
+            recurse_depth=recurse_depth,
         )
 
     def search_for_crossline_patterns(
@@ -987,12 +1001,36 @@ class App(object):
     def get_alert_actions(self):
         return alert_actions.AlertActions(self)
 
-    def get_custom_commands(self):
-        return custom_commands.CustomCommands(self)
+    def get_custom_commands(self, config=None):
+        """Return a CustomCommands instance optionally supporting class-based
+        checks config ConfigurationProxy / MergedConfigurationProxy
 
-    def get_custom_executable_files(self, local=None):
+        Args:
+            config (ConfigurationProxy|MergedConfigurationProxy): a set of
+                configurations to be checked. Defaults to None.
+
+        Returns:
+            CustomCommands: An instance of CustomCommands for interacting with
+                architecture-specific command files and associated conf settings
+        """
+        return custom_commands.CustomCommands(self, config)
+
+    def get_custom_executable_files(self, config=None, local=False):
+        """Retrieve custom command executable files
+
+        Args:
+            config (ConfigurationProxy|MergedConfigurationProxy): a set of
+                configurations to be checked. Defaults to None.
+            local (bool): If True, include commands with `command.local` set
+                to a true truthy value (local to the search head), otherwise
+                return commands without `command.local` or set to a false truthy
+                value. Defaults to False.
+
+        Returns:
+            List[FileResource]: `FileResource`s corresponding to desired command files
+        """
         executable_files = []
-        custom_commands = self.get_custom_commands()
+        custom_commands = self.get_custom_commands(config)
         for command in custom_commands.get_commands():
             # If set to "true", specifies that the command should be run on the search head only.
             if local is False and command.local:
@@ -1008,11 +1046,68 @@ class App(object):
                     executable_files.append(execute_file.relative_path)
         return executable_files
 
-    def get_non_distributed_files(self):
-        return self.distsearch_conf().get_replication_blacklist_files()
+    def get_non_distributed_files(self, config):
+        if "distsearch" not in config:
+            return []
+        conf_file = config["distsearch"]
+        if (
+            not conf_file.has_section("replicationBlacklist") and
+            not conf_file.has_section("replicationDenylist")
+            ):
+            return []
 
-    def get_transforms_executable_files(self):
-        return self.transforms_conf().get_external_executable_file_path_list()
+        denylist_files = set()
+        regexes = []
+        for section_name in ("replicationBlacklist", "replicationDenylist"):
+            if not conf_file.has_section(section_name):
+                continue
+            section = conf_file.get_section(section_name)
+            for _, regex in section.options.items():
+                regexes.append(regex.value)
+
+        for directory, filename, _ in self.iterate_files():
+            file_path = os.path.join(directory, filename)
+            regex_file_path = os.path.join(
+                "apps", self.package.origin_package_name, file_path
+            )
+
+            for regex in regexes:
+                try:
+                    if re.match(rf"{regex}", regex_file_path):
+                        denylist_files.add(file_path)
+                except re.error as ex:
+                    logger.warning(f"error={ex}")
+                    continue
+
+        return list(denylist_files)
+
+    def get_transforms_executable_files(self, config):
+        """Retrieve a list of files from transforms.conf
+        `external_cmd = <file> <args>` properties.
+
+        Args:
+            config (ConfigurationProxy|MergedConfigurationProxy): a set of
+                configurations to be checked.
+
+        Returns:
+            List[str]: List of file names as they appear in transforms.conf
+        """
+        if not "transforms" in config:
+            return []
+        conf_file = config["transforms"]
+        external_commands = set()
+        for section in conf_file.sections():
+            if section.has_option("external_cmd"):
+                external_commands.add(section.get_option("external_cmd").value)
+        executable_files = []
+        for external_command in external_commands:
+            executable_files.append(external_command.strip().split(" ")[0])
+        files = []
+        for file_name in executable_files:
+            relative_path = os.path.join("bin", file_name)
+            if self.file_exists(relative_path):
+                files.append(relative_path)
+        return files
 
     def get_custom_visualizations(self):
         return custom_visualizations.CustomVisualizations(self)
@@ -1020,14 +1115,11 @@ class App(object):
     def get_modular_inputs(self):
         return modular_inputs.ModularInputs.factory(self)
 
-    def get_rest_map(self, dir="default"):
-        return rest_map.RestMap(self, dir)
+    def get_rest_map(self, config):
+        return rest_map.RestMap(self, config)
 
-    def get_saved_searches(self):
-        return saved_searches.SavedSearches(self)
-
-    def get_workflow_actions(self):
-        return workflow_actions.WorkFlowActions(self)
+    def get_saved_searches(self, config):
+        return saved_searches.SavedSearches(self, config)
 
     # ---------------------------------
     # ConfFile Helper Definitions
@@ -1053,13 +1145,6 @@ class App(object):
             config_file=authorize_configuration_file.AuthorizeConfigurationFile(),
         )
 
-    def distsearch_conf(self, dir="default"):
-        return self.get_config(
-            "distsearch.conf",
-            dir=dir,
-            config_file=distsearch_configuration_file.DistsearchConfigurationFile(self),
-        )
-
     def indexes_conf(self, dir="default"):
         return self.get_config(
             "indexes.conf",
@@ -1088,13 +1173,6 @@ class App(object):
             config_file=props_configuration_file.PropsConfigurationFile(),
         )
 
-    def transforms_conf(self, dir="default"):
-        return self.get_config(
-            "transforms.conf",
-            dir=dir,
-            config_file=transforms_configuration_file.TransformsConfigurationFile(self),
-        )
-
     def web_conf(self, dir="default"):
         return self.get_config(
             "web.conf",
@@ -1181,6 +1259,16 @@ class App(object):
         Returns:
             FileView: a FileView looking at the given path"""
         return file_view.FileView(self, os.path.join(*paths) if paths else "")
+    
+    @property
+    def custom_conf_files(self):
+        if self._custom_conf_files is None:
+            self._custom_conf_files = set()
+            for (relative_file_path, _) in self.get_filepaths_of_files(types=[".conf"], basedir=["default", "local"]):
+                filename = os.path.basename(relative_file_path)
+                if filename not in SPLUNK_DEFINED_CONFS:
+                    self._custom_conf_files.add(relative_file_path)
+        return self._custom_conf_files
 
     @property
     def lookups(self):
