@@ -38,6 +38,24 @@ def get_dashboard_nodes(xmlfiles):
     return findings
 
 
+def get_dashboard_nodes_all(app, file_view):
+    """
+    Helper function to return SXML dashboard root nodes
+    """
+    findings = []
+    try:
+        for (directory, filename, ext) in file_view.iterate_files(basedir="ui/views"):
+            relative_filepath = os.path.join(directory, filename)
+            full_filepath = app.get_filename(directory, filename)
+            rootnode = etree.parse(full_filepath, parser=etree.XMLParser(recover=True))
+            if rootnode.getroot().tag == "dashboard" or rootnode.getroot().tag == "form":
+                findings.append((rootnode.getroot(), relative_filepath))
+    except Exception as exception:
+        print(f"Exception while getting dashboard nodes: {exception}")
+
+    return findings
+
+
 def find_xml_nodes_usages(xml_files, nodes):
     """
     Helper function to find xml node usage
@@ -56,6 +74,26 @@ def find_xml_nodes_usages(xml_files, nodes):
     return findings
 
 
+def find_xml_nodes_usages_all(app, file_view, nodes):
+    """
+    Helper function to find xml node usage
+    """
+    #  Outputs not_applicable if no xml files found
+    findings = []
+    for (directory, filename, ext) in file_view.iterate_files(basedir="ui/views"):
+        relative_filepath = os.path.join(directory, filename)
+        full_filepath = app.get_filename(directory, filename)
+        soup = bs4.BeautifulSoup(open(full_filepath, "rb"), "lxml-xml")
+        for node in nodes:
+            if hasattr(node, "attrs"):
+                findings_per_file = soup.find_all(node.name, attrs=node.attrs)
+            else:
+                findings_per_file = soup.find_all(node.name)
+            findings_per_file = [(e, relative_filepath) for e in findings_per_file]
+            findings += findings_per_file
+    return findings
+
+
 def unpack_absolute_path(paths_tuple):
     """This function
     1. unpacks a tuple
@@ -229,6 +267,7 @@ def get_imported_matches(file):
                 matches.append(match)
     return matches
 
+
 def parse_static_match(match, prefix):
     """Utility function that parses a static file match into a require-style import.
 
@@ -279,10 +318,10 @@ def get_static_matches(file):
     pattern = re.compile(r"(\/static\/)[^\"|\']+")
     for matched_object in pattern.finditer(file):
         candiate = matched_object.group()
-        match = parse_static_match(candiate, 'js')
+        match = parse_static_match(candiate, "js")
         if match and match not in matches:
             matches.append(match)
-        match = parse_static_match(candiate, 'build')
+        match = parse_static_match(candiate, "build")
         if match and match not in matches:
             matches.append(match)
     return matches
