@@ -6,14 +6,17 @@ checks. One group consists of many checks. Implementation wise, each file in
 the folder of splunk_appinspect/checks/ is a group. Inside each on of those
 files are checks.
 """
+import functools
 import imp
 import inspect
+import itertools
 import logging
 import operator
 import os
 import re
 import sys
 from builtins import str as text
+from collections import defaultdict
 from typing import Sequence
 from dataclasses import dataclass
 
@@ -833,7 +836,7 @@ class Check(object):
 
     def _implemented(self, method_name):
         """Returns True and the method if this method_name was implemented by the
-        child class, False otherwise.
+        child class, (False, None) otherwise.
 
         Args:
             method_name (str): method name to interrogate
@@ -843,7 +846,7 @@ class Check(object):
             (False, None) otherwise
         """
         # Get the method, this may or may not be the parent method
-        method = getattr(self, method_name, None) 
+        method = getattr(self, method_name, None)
         if method is None:
             return False, None
         # Get the parent method
@@ -867,16 +870,20 @@ class Check(object):
 
         Yields:
             Subclass of CheckMessage depending on the result"""
+        should_check = {}
+        did_check = defaultdict(lambda: False)
+
         config_check_methods = (
             "check_config",
             "check_default_config",
             "check_merged_config",
             "check_local_config",
         )
-        should_check_config = any(
+        should_check["config"] = any(
             [self._implemented(method_name)[0] for method_name in config_check_methods]
         )
-        if should_check_config:
+
+        if should_check["config"]:
             depends_on_config = self._config.depends_on_config or []
             configs_to_check = []
             for location in ("default", "local", "merged"):
@@ -893,31 +900,27 @@ class Check(object):
                 if location in ("default", "merged"):
                     # Do not run check_config for local
                     configs_to_check.append(config)
-                impl, check_method = self._implemented(f"check_{location}_config")
+                check_method_name = f"check_{location}_config"
+                impl, check_method = self._implemented(check_method_name)
                 if impl and callable(check_method):
+                    did_check["config"] = True
                     yield from check_method(app, config) or []
 
-            if self._implemented("check_config"):
+            if self._implemented("check_config")[0] and configs_to_check:
+                did_check["config"] = True
                 for config in configs_to_check:
                     yield from self.check_config(app, config) or []
 
-            if depends_on_config and not configs_to_check:
-                for conf_file_depends in depends_on_config:
-                    if conf_file_depends not in app.merged_config:
-                        yield NotApplicableMessage(
-                            f"{conf_file_depends}.conf does not exist"
-                        )
-
         data_check_methods = (
             "check_data",
             "check_default_data",
             "check_merged_data",
             "check_local_data",
         )
-        should_check_data = any(
+        should_check["data"] = any(
             [self._implemented(method_name)[0] for method_name in data_check_methods]
         )
-        if should_check_data:
+        if should_check["data"]:
             depends_on_data = self._config.depends_on_data or []
             file_views_to_check = []
             for location in ("default", "local", "merged"):
@@ -932,24 +935,17 @@ class Check(object):
                 ):
                     continue
                 file_views_to_check.append(loc_file_view["data"])
-                impl, check_method = self._implemented(f"check_{location}_data")
+                check_method_name = f"check_{location}_data"
+                impl, check_method = self._implemented(check_method_name)
                 if impl and callable(check_method):
+                    did_check["data"] = True
                     yield from check_method(app, loc_file_view["data"]) or []
 
-            if self._implemented("check_data"):
+            if self._implemented("check_data")[0] and file_views_to_check:
+                did_check["data"] = True
                 for loc_file_view in file_views_to_check:
                     yield from self.check_data(app, loc_file_view) or []
 
-            if depends_on_data and not file_views_to_check:
-                for data_depends in depends_on_data:
-                    if (
-                        "data" not in app.merged_file_view
-                        or data_depends not in app.merged_file_view["data"]
-                    ):
-                        yield NotApplicableMessage(
-                            f"{os.path.join('data', data_depends)} does not exist"
-                        )
-
         # If app has lookups, run lookup checks
         for location in ("lookups", "metadata", "static"):
             if location.endswith("s"):
@@ -961,17 +957,61 @@ class Check(object):
 
             all_impl, check_all_method = self._implemented(check_all_method_name)
             one_impl, check_one_method = self._implemented(check_one_method_name)
-            if app.directory_exists(location):
-                file_view = app.get_file_view(location)
-                if all_impl and callable(check_all_method):
-                    yield from check_all_method(app, file_view) or []
 
-                if one_impl and callable(check_one_method):
-                    for (directory, filename, _) in file_view.iterate_files():
-                        yield from check_one_method(app, os.path.join(directory, filename)) or []
-            elif all_impl or one_impl:
-                yield NotApplicableMessage(f"The `{location}` directory does not exist.")
+            should_check[location] = all_impl or one_impl
 
+            if not app.directory_exists(location):
+                continue
+
+            file_view = app.get_file_view(location)
+            if all_impl and callable(check_all_method):
+                did_check[location] = True
+                yield from check_all_method(app, file_view) or []
+
+            if one_impl and callable(check_one_method):
+                did_check[location] = True
+                for (directory, filename, _) in file_view.iterate_files():
+                    yield from check_one_method(app, os.path.join(directory, filename)) or []
+
+        other_check_methods = [
+            value
+            for (_, value) in inspect.getmembers(
+                self,
+                predicate=lambda member: callable(member) and getattr(member, "is_check_method", False)
+            )
+        ]
+
+        for check_method in other_check_methods:
+            should_check[check_method.__name__] = True
+
+            did_check[check_method.__name__], check_results = check_method(app)
+
+            if not did_check[check_method.__name__]:
+                continue
+
+            yield from check_results or []
+
+        if not any([did_check[loc] for loc in should_check]):
+            if should_check["config"]:
+                for conf_file_depends in depends_on_config:
+                    yield NotApplicableMessage(
+                        f"{conf_file_depends}.conf does not exist"
+                    )
+
+            if should_check["data"]:
+                for data_depends in depends_on_data:
+                    yield NotApplicableMessage(
+                        f"{os.path.join('data', data_depends)} does not exist"
+                    )
+
+            for location in ("lookups", "metadata", "static"):
+                if should_check[location]:
+                    yield NotApplicableMessage(f"The `{location}` directory does not exist.")
+
+            for check_method in other_check_methods:
+                if check_method.not_applicable_message is None:
+                    continue
+                yield NotApplicableMessage(check_method.not_applicable_message)
 
     def check_config(self, app, config):
         """Use this method to check configs across default and the merged view using the same logic
@@ -983,7 +1023,7 @@ class Check(object):
           2) With the `config` argument equal to a `MergedConfigurationProxy` representing the merged
              configuration of local and default if `depends_on_config` is specified AND at least one
              of the configs in `depends_on_config` exists within `<app>/[default|local]/<config>.conf`
-    
+
         Args:
             app (App): the app to be checked
             config (ConfigurationProxy|MergedConfigurationProxy): a set of configuration to be checked
@@ -1194,36 +1234,185 @@ class Check(object):
         Yields:
             Subclass of CheckMessage depending on the result"""
         raise NotImplementedError("Method `check_static_file` has not been implemented")
-
-    @classmethod
-    def disallowed_config_stanza(
-        cls, conf_file, stanza, tags, cert_min_version=None, cert_max_version=None
+    
+    @staticmethod
+    def depends_on_files(
+        basedir="",
+        excluded_dirs=None,
+        types=None,
+        names=None,
+        excluded_types=None,
+        excluded_bases=None,
+        recurse_depth=float("inf"),
+        not_applicable_message=None,
     ):
-        """Helper method to produce Check classes that simply check for the presence of a
-        forbidden stanza in a given config file.
+        """This method is used to decorate custom check methods which are tied to the existence
+        of arbitrary files.
 
         Args:
-            conf_file (str): name of configuration file (without `.conf`) where `stanza` is
+            not_applicable_message (str): the message used to generate a NotApplicableMessage if
+                                          no matching files are found.
+
+            See App.iterate_files for other args
+        
+        Returns:
+            A decorator that will set attributes on the decorated method"""
+        def decorator(func):
+            @functools.wraps(func)
+            def check_method(self, app):
+                files = list(app.iterate_files(
+                    basedir=basedir,
+                    excluded_dirs=excluded_dirs,
+                    types=types,
+                    names=names,
+                    excluded_types=excluded_types,
+                    excluded_bases=excluded_bases,
+                    recurse_depth=recurse_depth,
+                ))
+                if not files:
+                    return False, []
+                
+                return True, itertools.chain(
+                    *(func(self, app, os.path.join(directory, filename)) for (directory, filename, _) in files)
+                )
+
+            check_method.is_check_method = True
+            check_method.not_applicable_message = not_applicable_message
+            return check_method
+
+        return decorator
+    
+    @staticmethod
+    def depends_on_matching_files(
+        patterns,
+        basedir="",
+        excluded_dirs=None,
+        types=None,
+        names=None,
+        excluded_types=None,
+        excluded_bases=None,
+        recurse_depth=float("inf"),
+        not_applicable_message=None,
+    ):
+        """This method is used to decorate custom check methods which are tied to the existence
+        of arbitrary files that match one or more regular expressions.
+
+        Args:
+            not_applicable_message (str): the message used to generate a NotApplicableMessage if
+                                          no matching files are found.
+
+            See App.search_for_patterns for other args
+        
+        Returns:
+            A decorator that will set attributes on the decorated method"""
+        def match_to_check_method_args(match):
+            (relative_file_ref_output, file_match) = match
+            relative_filepath, line_number = relative_file_ref_output.rsplit(":", 1)
+            return (relative_filepath, int(line_number), file_match)
+
+        def decorator(func):
+            @functools.wraps(func)
+            def check_method(self, app):
+                files = app.search_for_patterns(
+                    patterns,
+                    basedir=basedir,
+                    excluded_dirs=excluded_dirs,
+                    types=types,
+                    names=names,
+                    excluded_types=excluded_types,
+                    excluded_bases=excluded_bases,
+                    recurse_depth=recurse_depth,
+                )
+                if not files:
+                    return False, []
+                
+                # search_for_patterns returns a tuple of (relative_file_ref_output, file_match)
+                # - relative_file_ref_output is f"{relative_filepath}:{line_number}"
+                # - file_match is the match object from re.finditer
+                # we need to extract the file_path and line_number to pass into the check method
+                # instead of making check methods do that themselves. that's what match_to_check_method_args
+                # does.
+                files = map(match_to_check_method_args, files)
+
+                return True, itertools.chain(
+                    *(
+                        func(self, app, relative_filepath, line_number, file_match)
+                        for (relative_filepath, line_number, file_match) in files
+                    )
+                )
+                
+                # for (relative_file_ref_output, file_match) in files:
+                #     relative_filepath, line_number = relative_file_ref_output.rsplit(":", 1)
+                #     yield from func(self, app, relative_filepath, line_number, file_match) or []
+                
+                # return True, itertools.chain(
+                #     func(self, app, os.path.join(directory, filename)) for (directory, filename, _) in files
+                # )
+
+            check_method.is_check_method = True
+            check_method.not_applicable_message = not_applicable_message
+            return check_method
+
+        return decorator
+
+    @classmethod
+    def disallowed_config_stanza_patterns(
+        cls,
+        conf_file,
+        patterns,
+        tags,
+        check_name,
+        check_description,
+        reporter_action=FailMessage,
+        message=None,
+        reason=None,
+        remediation=None,
+        cert_min_version=None,
+        cert_max_version=None,
+        exceptions_predicate=None,
+        module=None,
+    ):
+        """Helper method to produce Check classes that simply check for the presence of one of
+        several forbidden stanzas in a given config file.
+
+        Args:
+            conf_file (str): name of configuration file (without `.conf`) where `stanzas` are
                 prohibited
-            stanza (str): name of configuration stanza that is prohibited
+            stanzas (:obj:`list` of :obj:`re.Pattern`): list of regex patterns matching prohibited
+                stanzas
             tags (:obj:`list` of :obj:`str`): tags where this check should apply
+            check_name (str): name of the check as reported to consumers
+            check_description (str): a description of what the check does
+            reporter_action (:obj:`CheckMessage`): messages that may be yielded by Checks
+            message (str): message given to CheckMessage
+            reason (str): reason for notification to be passed to user if matching stanza exists
+            remediation (str): remediation given to CheckMessage
             cert_min_version (:obj:`str`, optional): Minimum certification version where this
                 check applies, parsed as a semantic version number. Defaults to None
             cert_max_version (:obj:`str`, optional): Maximum certification version where this
                 check applies, parsed as a semantic version number. Defaults to None
+            exceptions_predicate(:obj:`callable`): An optional function that takes one argument
+                (the `app` object being inspected) and returns True/False. If it returns True, the
+                check is considered a success. Defaults to None
 
         Returns:
             Subclass of Check (not an instance) that looks for prohibited configuration stanzas"""
 
-        check_name = f"check_for_disallowed_{stanza}_in_{conf_file}_conf"
+        if message is None:
+            message = "{file_name} contains a [{stanza}] stanza, which is not allowed in Splunk Cloud."
 
-        class DisallowedConfigStanzaCheck(Check):
+        if reason:
+            message = f"{message} Details: {reason}"
+
+        if remediation is None:
+            remediation = "Remove the [{stanza}] stanza"
+
+        class DisallowedConfigStanzaPatternCheck(Check):
             def __init__(self):
                 super().__init__(
                     config=CheckConfig(
                         name=check_name,
-                        description=f"Check for disallowed stanza `{stanza}` in {conf_file}.conf. "
-                        f"Splunk Cloud prohibits the use of `{stanza}` in {conf_file}.conf",
+                        description=check_description,
                         cert_min_version=cert_min_version,
                         cert_max_version=cert_max_version,
                         tags=tags,
@@ -1232,25 +1421,314 @@ class Check(object):
                 )
 
             def check_config(self, app, config):
-                if not config[conf_file].has_section(stanza):
+                if callable(exceptions_predicate) and exceptions_predicate(app):
                     return
 
-                section = config[conf_file][stanza]
-                yield FailMessage(
-                    f"{section.get_relative_path()} contains a [{section.name}] stanza, "
-                    "which is not allowed in Splunk Cloud.",
-                    file_name=section.get_relative_path(),
-                    line_number=section.get_line_number(),
-                    remediation=f"Remove the [{section.name}] stanza",
-                )
+                for stanza in config[conf_file].section_names():
+                    if not any(pattern.match(stanza) for pattern in patterns):
+                        continue
+
+                    section = config[conf_file][stanza]
+                    yield reporter_action(
+                        message.format(
+                            stanza=section.name,
+                            file_name=section.get_relative_path(),
+                            line_number=section.get_line_number()
+                        ),
+                        file_name=section.get_relative_path(),
+                        line_number=section.get_line_number(),
+                        remediation=remediation.format(
+                            stanza=section.name,
+                            file_name=section.get_relative_path(),
+                            line_number=section.get_line_number()
+                        ),
+                    )
 
         # Get the module where this method was called, rather than using this module
-        DisallowedConfigStanzaCheck.__module__ = inspect.getmodule(
-            inspect.stack()[1][0]
+        if module is None:
+            module = inspect.getmodule(inspect.stack()[1][0])
+        DisallowedConfigStanzaPatternCheck.__module__ = module
+
+        return DisallowedConfigStanzaPatternCheck
+
+    @classmethod
+    def disallowed_config_stanza_pattern(
+        cls,
+        conf_file,
+        pattern,
+        tags,
+        check_name,
+        check_description,
+        reporter_action=FailMessage,
+        message=None,
+        reason=None,
+        remediation=None,
+        cert_min_version=None,
+        cert_max_version=None,
+        exceptions_predicate=None
+    ):
+        """Helper method to produce Check classes that simply check for the presence of one of
+        several forbidden stanzas in a given config file. See Check.disallowed_config_stanza_patterns for arg
+        names and descriptions.
+
+        Returns:
+            Subclass of Check (not an instance) that looks for a prohibited configuration stanza"""
+
+        DisallowedConfigStanzaPatternCheck = cls.disallowed_config_stanza_patterns(
+            conf_file,
+            [pattern],
+            tags,
+            check_name=check_name,
+            check_description=check_description,
+            reporter_action=reporter_action,
+            message=message,
+            reason=reason,
+            remediation=remediation,
+            cert_min_version=cert_min_version,
+            cert_max_version=cert_max_version,
+            exceptions_predicate=exceptions_predicate,
+            module=inspect.getmodule(inspect.stack()[1][0])
+        )
+
+        return DisallowedConfigStanzaPatternCheck
+
+    @classmethod
+    def disallowed_config_stanzas(
+        cls,
+        conf_file,
+        stanzas,
+        tags,
+        check_name,
+        check_description=None,
+        reporter_action=FailMessage,
+        message=None,
+        reason=None,
+        remediation=None,
+        cert_min_version=None,
+        cert_max_version=None,
+        exceptions_predicate=None,
+        module=None
+    ):
+        """Helper method to produce Check classes that simply check for the presence of one of
+        several forbidden stanzas in a given config file.
+
+        Args:
+            conf_file (str): name of configuration file (without `.conf`) where `stanzas` are
+                prohibited
+            stanzas (:obj:`list` of :obj:`str`): list of configuration stanzas that are
+                prohibited
+            tags (:obj:`list` of :obj:`str`): tags where this check should apply
+            check_name (str): name of the check as reported to consumers
+            check_description (str): a description of what the check does
+            reporter_action (:obj:`CheckMessage`): messages that may be yielded by Checks
+            message (str): message given to CheckMessage
+            reason (str): reason for notification to be passed to user if matching stanza exists
+            remediation (str): remediation given to CheckMessage
+            cert_min_version (:obj:`str`, optional): Minimum certification version where this
+                check applies, parsed as a semantic version number. Defaults to None
+            cert_max_version (:obj:`str`, optional): Maximum certification version where this
+                check applies, parsed as a semantic version number. Defaults to None
+            exceptions_predicate(:obj:`callable`): An optional function that takes one argument
+                (the `app` object being inspected) and returns True/False. If it returns True, the
+                check is considered a success. Defaults to None
+
+        Returns:
+            Subclass of Check (not an instance) that looks for prohibited configuration stanzas"""
+
+        if check_description is None:
+            check_description = f"Check for disallowed stanzas in {conf_file}.conf."
+
+        if message is None:
+            message = "{file_name} contains a [{stanza}] stanza, which is not allowed in Splunk Cloud."
+
+        if reason:
+            message = f"{message} Details: {reason}"
+
+        if remediation is None:
+            remediation = "Remove the [{stanza}] stanza"
+
+        class DisallowedConfigStanzaCheck(Check):
+            def __init__(self):
+                super().__init__(
+                    config=CheckConfig(
+                        name=check_name,
+                        description=check_description,
+                        cert_min_version=cert_min_version,
+                        cert_max_version=cert_max_version,
+                        tags=tags,
+                        depends_on_config=(conf_file,),
+                    )
+                )
+
+            def check_config(self, app, config):
+                if callable(exceptions_predicate) and exceptions_predicate(app):
+                    return
+
+                for stanza in stanzas:
+                    if not config[conf_file].has_section(stanza):
+                        continue
+
+                    section = config[conf_file][stanza]
+                    yield reporter_action(
+                        message.format(
+                            stanza=section.name,
+                            file_name=section.get_relative_path(),
+                            line_number=section.get_line_number()
+                        ),
+                        file_name=section.get_relative_path(),
+                        line_number=section.get_line_number(),
+                        remediation=remediation.format(
+                            stanza=section.name,
+                            file_name=section.get_relative_path(),
+                            line_number=section.get_line_number()
+                        ),
+                    )
+
+        # Get the module where this method was called, rather than using this module
+        if module is None:
+            module = inspect.getmodule(inspect.stack()[1][0])
+        DisallowedConfigStanzaCheck.__module__ = module
+
+        return DisallowedConfigStanzaCheck
+
+    @classmethod
+    def disallowed_config_stanza(
+        cls,
+        conf_file,
+        stanza,
+        tags,
+        check_name=None,
+        check_description=None,
+        reporter_action=FailMessage,
+        message=None,
+        reason=None,
+        remediation=None,
+        cert_min_version=None,
+        cert_max_version=None,
+        exceptions_predicate=None
+    ):
+        """Helper method to produce Check classes that simply check for the presence of a
+        forbidden stanza in a given config file. See Check.disallowed_config_stanzas for arg
+        names and descriptions.
+
+        Returns:
+            Subclass of Check (not an instance) that looks for a prohibited configuration stanza"""
+
+        if check_name is None:
+            check_name = f"check_for_disallowed_{stanza}_in_{conf_file}_conf"
+
+        if check_description is None:
+            check_description = f"Check that {conf_file}.conf does not contain a `[{stanza}]` stanza"
+
+        DisallowedConfigStanzaCheck = cls.disallowed_config_stanzas(
+            conf_file,
+            [stanza],
+            tags,
+            check_name=check_name,
+            check_description=check_description,
+            reporter_action=reporter_action,
+            message=message,
+            reason=reason,
+            remediation=remediation,
+            cert_min_version=cert_min_version,
+            cert_max_version=cert_max_version,
+            exceptions_predicate=exceptions_predicate,
+            module=inspect.getmodule(inspect.stack()[1][0])
         )
 
         return DisallowedConfigStanzaCheck
 
+    @classmethod
+    def disallowed_config_file(
+        cls,
+        conf_file,
+        tags,
+        check_name=None,
+        check_description=None,
+        reporter_action=FailMessage,
+        message=None,
+        reason=None,
+        remediation=None,
+        cert_min_version=None,
+        cert_max_version=None,
+        exceptions_predicate=None,
+        module=None
+    ):
+        """Helper method to produce Check classes that simply check for the presence of a
+         a given config file.
+
+        Args:
+            conf_file (str): name of configuration file (without `.conf`) where `stanza` is
+                prohibited
+            tags (:obj:`list` of :obj:`str`): tags where this check should apply
+            check_name (str): name of the check as reported to consumers
+            check_description (str): a description of what the check does
+            reporter_action (:obj:`CheckMessage`): messages that may be yielded by Checks
+            message (str):  messages formatting of reporter yielded
+            reason (str): reason for notification to be passed to user if matching stanza exists
+            remediation (str): remediation given to CheckMessage
+            cert_min_version (:obj:`str`, optional): Minimum certification version where this
+                check applies, parsed as a semantic version number. Defaults to None
+            cert_max_version (:obj:`str`, optional): Maximum certification version where this
+                check applies, parsed as a semantic version number. Defaults to None
+            exceptions_predicate(:obj:`callable`): An optional function that takes one argument
+                (the `app` object being inspected) and returns True/False. If it returns True, the
+                check is considered a success. Defaults to None
+
+
+        Returns:
+            Subclass of Check (not an instance) that looks for prohibited configuration file"""
+
+        if check_name is None:
+            check_name = f"check_{conf_file}_conf_does_not_exist"
+
+        if check_description is None:
+            check_description = f"Check that the app does not create {conf_file}."
+
+        if message is None:
+            message = "App contains {file_name}, which is not allowed in Splunk Cloud."
+
+        if reason:
+            message = f"{message} Details: {reason}"
+
+        if remediation is None:
+            remediation = "Remove {file_name} from your app."
+
+        class DisallowedConfigFileCheck(Check):
+            def __init__(self):
+                super().__init__(
+                    config=CheckConfig(
+                        name=check_name,
+                        description=check_description,
+                        cert_min_version=cert_min_version,
+                        cert_max_version=cert_max_version,
+                        tags=tags,
+                        depends_on_config=(conf_file,),
+                    )
+                )
+
+            def check_config(self, app, config):
+                if callable(exceptions_predicate) and exceptions_predicate(app):
+                    return
+
+                if conf_file in config:
+                    yield reporter_action(
+                        message.format(
+                            file_name=config[conf_file].get_relative_path()
+                        ),
+                        file_name=config[conf_file].get_relative_path(),
+                        remediation=remediation.format(
+                            file_name=config[conf_file].get_relative_path()
+                        ),
+                    )
+
+        # Get the module where this method was called, rather than using this module
+        if module is None:
+            module = inspect.getmodule(inspect.stack()[1][0])
+        DisallowedConfigFileCheck.__module__ = module
+
+        return DisallowedConfigFileCheck
+
 
 @dataclass
 class CheckConfig:
