@@ -13,6 +13,8 @@ import re
 import splunk_appinspect
 from splunk_appinspect import app_util
 from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
+from splunk_appinspect.checks import Check, CheckConfig
+from splunk_appinspect.check_messages import FailMessage
 
 report_display_order = 2
 logger = logging.getLogger(__name__)
@@ -45,7 +47,7 @@ def check_validate_no_duplicate_stanzas_in_conf_files(app, reporter):
                 reporter.fail(reporter_output, key[0], lineno)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.12")
 def check_config_file_parsing(app, reporter, included_tags):
     """Check that all config files parse cleanly- no trailing whitespace after
@@ -72,7 +74,7 @@ def check_config_file_parsing(app, reporter, included_tags):
             raise
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_no_default_stanzas(app, reporter):
     """Check that app does not contain any .conf files that create global
@@ -151,7 +153,7 @@ def check_inputs_conf_for_global_settings(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_manipulation_outside_of_app_container(app, reporter):
     """Check that app conf files do not point to files outside the app container.
@@ -202,23 +204,30 @@ def check_manipulation_outside_of_app_container(app, reporter):
                         )
                         reporter.fail(reporter_output, full_filepath, lineno)
 
+class CheckCollectionsConfForSpecifiedNameFieldType(Check):
+    def __init__(self):
+        super().__init__(config=CheckConfig(
+            name="check_collections_conf_for_specified_name_field_type",
+            description="Check that the `field.<name>` type in collections.conf does not include `boolean`."
+                        "Use `bool` instead.",
+            depends_on_config=("collections",),
+            cert_min_version="2.2.0",
+            tags=(
+                "cloud",
+                "private_app",
+                "private_classic",
+                "private_victoria",
+                "migration_victoria", 
+            ),
+        ))
 
-@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
-@splunk_appinspect.cert_version(min="2.2.0")
-def check_collections_conf_for_specified_name_field_type(app, reporter):
-    """Check that the `filed.<name>` type in collections.conf does not include `boolean`.
-    Use `bool` instead.
-    """
-    if app.file_exists("default", "collections.conf"):
-        filename = os.path.join("default", "collections.conf")
-        collections_conf = app.collections_conf()
-        for section in collections_conf.sections():
-            for key, value, lineno in collections_conf.items(section.name):
-                if key.startswith("field.") and value == "boolean":
-                    reporter_output = (
-                        "The field type for filed.<name> in collections.conf includes"
-                        " `number|bool|string|time`, use bool to instead of boolean"
-                        f" Stanza: [{section.name}]."
-                        f" File: {filename}, Line: {lineno}."
+    def check_config(self, app, config):
+        for section in config["collections"].sections():
+            for key, value in iter(section.options.items()):
+                if key.startswith("field.") and value.value == "boolean":
+                    yield FailMessage(
+                        "The field type for filed.<name> in collections.conf includes "
+                        "`number|bool|string|time`, use bool to instead of boolean",
+                        file_name=config["collections"].get_relative_path(),
+                        line_number=config["collections"][section.name][key].get_line_number()
                     )
-                    reporter.fail(reporter_output, filename, lineno)
