@@ -4,19 +4,16 @@
 ### Documentation standards
 """
 
-# Python Standard Libraries
 import codecs
 import os
 
-# Third-Party Libraries
 import langdetect
 from langdetect import DetectorFactory
 from langdetect.lang_detect_exception import LangDetectException
 
-# Custom Libraries
 import splunk_appinspect
-from splunk_appinspect.splunk import normalizeBoolean
 from splunk_appinspect.app_util import find_readmes
+from splunk_appinspect.splunk import normalizeBoolean
 
 DetectorFactory.seed = 0
 report_display_order = 50
@@ -48,8 +45,8 @@ def check_basic_readme(app, reporter):
                 if os.stat(full_file_path).st_size > 0:
                     break
         else:
-            reporter_output = "README file(s) found but appear to be empty. File: {}".format(
-                readme
+            reporter_output = (
+                f"README file(s) found but appear to be empty. File: {readme}"
             )
             reporter.fail(reporter_output, readme)
 
@@ -75,14 +72,14 @@ def check_documentation_language(app, reporter):
                 lang = langdetect.detect(contents)
                 if lang != "en":
                     reporter_output = (
-                        'Language for README appears to be in "{}",'
+                        f'Language for README appears to be in "{lang}",'
                         ' not "en". Please verify this manually.'
-                        " File: {}"
-                    ).format(lang, readme)
+                        f" File: {readme}"
+                    )
                     reporter.manual_check(reporter_output, readme)
         except (UnicodeDecodeError, LangDetectException):
             reporter_output = (
-                "Could not detect language of README file." " File: {}".format(readme)
+                f"Could not detect language of README file. File: {readme}"
             )
             reporter.manual_check(reporter_output, readme)
 
@@ -162,9 +159,7 @@ def check_archived_files(app, reporter):
     )
     if archived_files:
         for _, file, _ in archived_files:
-            reporter_output = (
-                "Found archived {}. Please make sure any archived files in the app are documented."
-            ).format(file)
+            reporter_output = f"Found archived {file}. Please make sure any archived files in the app are documented."
             reporter.manual_check(reporter_output)
     else:
         reporter_output = "No archived files found in app."
