@@ -8,10 +8,16 @@ These checks validate that a Splunk app has been correctly packaged, and can be
 import logging
 import os
 import stat
+import json
 from functools import wraps
 
+from packaging import version
+
 import splunk_appinspect
 from splunk_appinspect.app_util import AppVersionNumberMatcher
+from splunk_appinspect.app_configuration_file import _is_check_app_config_file
+from splunk_appinspect.checks import Check, CheckConfig
+from splunk_appinspect.check_messages import FailMessage, SkipMessage, WarningMessage
 
 report_display_order = 1
 logger = logging.getLogger(__name__)
@@ -47,6 +53,7 @@ def app_package_extractable(check):
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -72,6 +79,7 @@ def check_that_splunk_app_package_has_read_permission(app, reporter):
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -93,6 +101,7 @@ def check_that_splunk_app_package_valid_compressed_file(app, reporter):
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -125,6 +134,7 @@ def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter)
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -150,6 +160,7 @@ def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
@@ -199,12 +210,13 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
 def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_folder(
-    app, reporter
+        app, reporter
 ):
     """Check that the Splunk App package with a .dependencies directory also
     contains exactly one valid app folder.
@@ -234,10 +246,10 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
         app.package.working_app_path, app.package.working_artifact
     )
     if (
-        len(contents) != 2
-        or not all_contents_are_folders
-        or relative_dependencies_path not in contents
-        or relative_working_app_path not in contents
+            len(contents) != 2
+            or not all_contents_are_folders
+            or relative_dependencies_path not in contents
+            or relative_working_app_path not in contents
     ):
         reporter_output = (
             f"Only a single app folder and a single {app.dependencies_directory_path} "
@@ -255,12 +267,13 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
 def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
-    app, reporter
+        app, reporter
 ):
     """Check that the Splunk App package with a .dependencies directory also
     contains an app folder with an app.manifest.
@@ -298,6 +311,7 @@ def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
@@ -356,12 +370,13 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
 def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_files(
-    app, reporter
+        app, reporter
 ):
     """Check that the extracted Splunk App does not contain any directories or
     files that start with a `.`, or directories that start with `__MACOSX`.
@@ -387,6 +402,7 @@ def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_f
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -394,72 +410,164 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
     """Check that the extracted Splunk App contains a `default/app.conf`
     file.
     """
-    if not app.package.does_working_artifact_contain_default_app_conf():
-        reporter_output = (
-            "Splunk App packages must contain a"
-            " `default/app.conf file`."
-            f" No `default/app.conf` was found in `{app.package.origin_artifact_name}`."
+    _is_check_app_config_file(app, reporter, "fail")
+
+
+class CheckValidVersionNumber(Check):
+    def __init__(self):
+        super().__init__(config=CheckConfig(
+            name="check_valid_version_number",
+            description="Check that the extracted Splunk App contains a `default/app.conf` file "
+                        "that contains an `[id]` or `[launcher]` stanza with a `version` property that "
+                        "is formatted as `Major.Minor.Revision`.",
+            depends_on_config=("app",),
+            cert_min_version="1.5.0",
+            tags=(
+                "splunk_appinspect",
+                "appapproval",
+                "cloud",
+                "self-service",
+                "private_app",
+                "private_victoria",
+                "migration_victoria",
+            )
+        ))
+
+    @staticmethod
+    def _is_valid_version_number(version_number):
+        app_version_matcher = AppVersionNumberMatcher()
+
+        try:
+            parsed_version = version.parse(version_number)
+        except version.InvalidVersion:
+            return False
+        
+        if isinstance(parsed_version, version.LegacyVersion):
+            # If the version gets parsed as a LegacyVersion, that means it's not PEP-440 compatible
+            # Things like "1.3.xy123" and "whatchamacallit" both fall into this category
+            # We'll rely on regex and semver to decide if it's valid. This is acceptable because
+            # it's still a subset of what Splunkbase supports.
+            return bool(app_version_matcher.match(version_number))
+
+        return True
+
+    def check(self, app):
+        # Initialize the list of version
+        self._versions = []
+
+        # Run all of the check methods
+        yield from super().check(app) or []
+
+        # Verify that all of the versions match
+        if len(set([app_version for (_, _, _, _, app_version) in self._versions])) == 1:
+            return
+
+        for (file_name, stanza, property_name, line_number, app_version) in self._versions:
+            if line_number:
+                reporter_output = f"{app_version} specified in {property_name} in the " \
+                                  f"`[{stanza}]` stanza of {file_name} does not match other " \
+                                   "versions specified in the app. All version numbers specified in an app must match."
+            else:
+                reporter_output = f"{app_version} specified in {property_name} of {file_name} " \
+                                  "does not match other versions specified in the app. All " \
+                                  "version numbers specified in an app must match."
+                
+            yield FailMessage(
+                reporter_output,
+                file_name=file_name,
+                line_number=line_number,
+            )
+
+    def check_config(self, app, config):
+        SETTINGS_TO_CHECK = (
+            # (conf_file, section, option, action_if_missing, action_if_invalid)
+            ("id", "version", WarningMessage, FailMessage),
+            ("launcher", "version", WarningMessage, FailMessage),
         )
-        reporter.fail(reporter_output)
 
+        conf_versions = []
 
-@splunk_appinspect.tags(
-    "splunk_appinspect",
-    "appapproval",
-    "cloud",
-    "packaging_standards",
-    "self-service",
-    "private_app",
-    "private_victoria"
-)
-@splunk_appinspect.cert_version(min="1.5.0")
-def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_version_number(
-    app, reporter
-):
-    """Check that the extracted Splunk App contains a `default/app.conf` file
-    that contains an `[id]` or `[launcher]` stanza with a `version` property that
-    is formatted as `Major.Minor.Revision`.
-    """
+        conf_file = config["app"]
 
-    filename = os.path.join("default", "app.conf")
-    if not app.file_exists(filename):
-        reporter_output = (
-            "Splunk App packages must contain a"
-            " `default/app.conf file`."
-            " No `default/app.conf` was found "
-            f" in `{app.package.origin_artifact_name}`."
-        )
-        reporter.fail(reporter_output)
-        return
+        for (section_name, option_name, action_if_missing, action_if_invalid) in SETTINGS_TO_CHECK:
+            if not conf_file.has_section(section_name):
+                # Missing the config file or the section
+                yield action_if_missing(
+                    f"No `[{section_name}]` section found in app.conf file.",
+                    file_name=conf_file.get_relative_path() if conf_file else "default/app.conf"
+                )
+                continue
 
-    config = app.get_config(os.path.basename(filename))
-    matcher = AppVersionNumberMatcher()
+            section = conf_file.get_section(section_name)
 
-    # the matcher matches both x.x and x.x.x formats,
-    # so we expect 2 matches
+            if not section.has_option(option_name):
+                # Has the config file and section, but missing the option
+                yield action_if_missing(
+                    f"A `{option_name}` attribute formatted as Major.Minor.Revision is required in "
+                    f"the `[{section_name}]` stanza of app.conf.",
+                    file_name=section.get_relative_path(),
+                    line_number=section.get_line_number(),
+                )
+                continue
 
-    num_matches = 0
+            option = section.get_option(option_name)
 
-    if config.has_option("id", "version"):
-        version = config.get("id", "version")
-        num_matches = max(num_matches, len(matcher.match(version)))
+            if not self._is_valid_version_number(option.value):
+                yield action_if_invalid(
+                    f"The version {option.value} in the `{option_name}` attribute in the "
+                    f"`[{section_name}]` stanza of app.conf is invalid. Versions "
+                    "must be specified as `Major.Minor.Revision`.",
+                    file_name=option.get_relative_path(),
+                    line_number=option.get_line_number(),
+                )
 
-    if config.has_option("launcher", "version"):
-        version = config.get("launcher", "version")
-        num_matches = max(num_matches, len(matcher.match(version)))
+            conf_versions.append((
+                option.get_relative_path(),
+                section_name,
+                option_name,
+                option.get_line_number(),
+                option.value
+            ))
 
-    reporter_output = (
-        "`Major.Minor.Revision` version is required "
-        "in `[id]` or `[launcher]` section of app.conf. "
-    )
+        if len(conf_versions) == 0:
+            yield FailMessage(
+                "The `version` attribute must be specified in either the `[id]` or `[launcher]` "
+                "stanzas.",
+                file_name=conf_file.get_relative_path(),
+            )
 
-    if not num_matches:
-        reporter.fail(reporter_output, file_name=filename)
+        self._versions.extend(conf_versions)
 
-    if num_matches == 1:
-        # there's only an x.x version, so give a warning
-        reporter.warn(reporter_output, file_name=filename)
+    @Check.depends_on_files(names=["app.manifest"], recurse_depth=0)
+    def check_app_manifest(self, app, path_in_app):
+        try:
+            with open(app.get_filename(path_in_app), "r") as manifest_json_file:
+                manifest_json = json.load(manifest_json_file)
 
+            manifest_version = manifest_json.get("info").get("id").get("version")
+        except (ValueError, AttributeError):
+            # No version found in the app.manifest so don't try to validate it
+            pass
+        except Exception as exc:
+            yield SkipMessage("The `app.manifest` file could not be loaded.")
+        else:
+            if not self._is_valid_version_number(manifest_version):
+                yield FailMessage(
+                    f"App contains `app.manifest` but the version {manifest_version} specified in "
+                    "`info.id.version` attribute is invalid. Versions must be specified as "
+                    "`Major.Minor.Revision`.",
+                    file_name=path_in_app,
+                    remediation="Correct the value of `info.id.version`, or remove `app.manifest` "
+                                "if it is not required.",
+                )
+
+            self._versions.append((
+                path_in_app,
+                None,
+                "info.id.version",
+                None,
+                manifest_version
+            ))
 
 @splunk_appinspect.tags(
     "splunk_appinspect",
@@ -469,6 +577,7 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_ve
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
@@ -495,12 +604,13 @@ def check_that_extracted_splunk_app_does_not_contain_invalid_directories(app, re
     "self-service",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
 def check_that_extracted_splunk_app_does_not_contain_files_with_invalid_permissions(
-    app, reporter
+        app, reporter
 ):
     """Check that the extracted Splunk App does not contain any files
     with incorrect permissions. Files must have the owner's
@@ -517,7 +627,13 @@ def check_that_extracted_splunk_app_does_not_contain_files_with_invalid_permissi
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "cloud", "packaging_standards", "private_app"
+    "splunk_appinspect", 
+    "cloud", 
+    "packaging_standards", 
+    "private_app", 
+    "private_classic",
+    "private_victoria",
+    "migration_victoria",
 )
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_requires_adobe_flash(app, reporter):
