@@ -14,6 +14,8 @@ import os
 import re
 
 import splunk_appinspect
+from splunk_appinspect.check_messages import WarningMessage
+from splunk_appinspect.checks import Check, CheckConfig
 from splunk_appinspect.configuration_file import ConfigurationFile, ConfigurationSection
 from splunk_appinspect.splunk_pretrained_sourcetypes_list import (
     SPLUNK_PRETRAINED_SOURCETYPES,
@@ -79,7 +81,7 @@ def check_props_conf_has_transforms_option_and_transforms_conf_has_matching_stan
 
         if props_sections_with_transforms:
             if app.file_exists("default", "transforms.conf"):
-                transforms_config = app.transforms_conf()
+                transforms_config = app.get_config("transforms.conf")
                 for props_section in props_sections_with_transforms:
                     for setting in props_section.settings_with_key_pattern(
                         settings_key_regex_pattern
@@ -175,7 +177,7 @@ def check_props_conf_has_report_option_and_transforms_conf_has_matching_stanza(
 
             if props_sections_with_transforms:
                 if app.file_exists(directory, "transforms.conf"):
-                    transforms_config = app.transforms_conf(dir=directory)
+                    transforms_config = app.get_config("transforms.conf", directory)
                     for props_section in props_sections_with_transforms:
                         for setting in props_section.settings_with_key_pattern(
                             settings_key_regex_pattern
@@ -232,7 +234,8 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
 
             if props_sections_with_transforms:
                 if app.file_exists(directory, "transforms.conf"):
-                    transforms_config: ConfigurationFile = app.transforms_conf(
+                    transforms_config: ConfigurationFile = app.get_config(
+                        "transforms.conf",
                         directory
                     )
                     for props_section in props_sections_with_transforms:
@@ -393,76 +396,86 @@ def check_props_conf_regex_stanza_name_followed_by_double_colon(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
-@splunk_appinspect.cert_version(min="2.1.0")
-def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
-    """
-    Check that pretrained sourctypes in props.conf have only "TRANSFORM-" or "SEDCMD" settings,
-    and that those transforms only modify the host, source, or sourcetype.
-    """
+class CheckPretrainedSourcetypesHaveOnlyAllowedTransforms(Check):
+    def __init__(self):
+        super().__init__(
+            config=CheckConfig(
+                name="check_pretrained_sourcetypes_have_only_allowed_transforms",
+                description="Check that pretrained sourctypes in props.conf"
+                "have only 'TRANSFORM-' or 'SEDCMD' settings,"
+                "and that those transforms only modify the host, source, or sourcetype.",
+                depends_on_config=(
+                    "props",
+                ),
+                cert_min_version="2.1.0",
+                tags=(
+                    "splunk_appinspect",
+                    "cloud",
+                    "private_app",
+                    "private_victoria",
+                    "migration_victoria",
+                    "private_classic",
+                ),
+                report_display_order=2,
+            )
+        )
 
-    allowed_dest_keys = ["MetaData:Host", "MetaData:Source", "MetaData:Sourcetype"]
+    def check_config(self, app, config):
+        allowed_dest_keys = ["MetaData:Host", "MetaData:Source", "MetaData:Sourcetype"]
+        pretrained_sourcetype_sections = []
+        for section in config["props"].sections():
+            if section.name in SPLUNK_PRETRAINED_SOURCETYPES:
+                pretrained_sourcetype_sections.append(section)
 
-    props_file_path = os.path.join("default", "props.conf")
-    transforms_file_path = os.path.join("default", "transforms.conf")
-    if not app.file_exists(props_file_path):
-        reporter_output = "No props.conf file exists."
-        reporter.not_applicable(reporter_output)
-        return
-
-    # collect all the sections for pretrained sourcetypes
-    props_conf = app.props_conf()
-    pretrained_sourcetype_sections = []
-    for section in props_conf.sections():
-        if section.name in SPLUNK_PRETRAINED_SOURCETYPES:
-            pretrained_sourcetype_sections.append(section)
-
-    # do the checking
-    for section in pretrained_sourcetype_sections:
-        for setting in section.settings():
-
-            # these sections must have only "TRANSFORM-" or "SEDCMD-" settings
-            if not setting.name.startswith(
-                "TRANSFORMS-"
-            ) and not setting.name.startswith("SEDCMD"):
-                reporter_output = "Only TRANSFORMS- or SEDCMD options are allowed for pretrained sourcetypes."
-                reporter.warn(reporter_output, props_file_path, setting.lineno)
-                return
-
-            if setting.name.startswith("TRANSFORMS-"):
-                if not app.file_exists(transforms_file_path):
-                    reporter_output = (
-                        "No transforms.conf exists for setting in "
-                        f"props.conf: {setting.name}={setting.value}"
+        # do the checking
+        for section in pretrained_sourcetype_sections:
+            for setting in section.settings():
+                # these sections must have only "TRANSFORM-" or "SEDCMD-" settings
+                if not setting.name.startswith(
+                    "TRANSFORMS-"
+                ) and not setting.name.startswith("SEDCMD"):
+                    yield WarningMessage(
+                        "Only TRANSFORMS- or SEDCMD options are allowed for pretrained sourcetypes.",
+                        file_name=config["props"].get_relative_path(),
+                        line_number=setting.lineno,
                     )
-                    reporter.warn(reporter_output, props_file_path, setting.lineno)
                     return
-
-                transforms_conf = app.transforms_conf()
-
-                for transform_stanza_name in setting.value.replace(" ", "").split(","):
-
-                    if not transforms_conf.has_section(transform_stanza_name):
-                        reporter_output = (
-                            f"Transforms.conf does not contain a [{transform_stanza_name.strip()}] stanza"
-                            f"to match props.conf [{section.name}] {setting.name}={setting.value}"
-                        )
-                        reporter.warn(reporter_output, props_file_path, setting.lineno)
-                        return
-
-                    # the transforms may only modify the allowed fields
-                    transforms_section = transforms_conf.get_section(
-                        transform_stanza_name
-                    )
-                    if transforms_section.has_option("DEST_KEY"):
-                        dest = transforms_section.get_option("DEST_KEY")
-                        if dest.value not in allowed_dest_keys:
-                            reporter_output = (
-                                f"Modifying the {dest.value} field for "
-                                "a pretrained sourcetype is not allowed."
-                            )
-                            reporter.warn(
-                                reporter_output, transforms_file_path, dest.lineno
+                if setting.name.startswith("TRANSFORMS-"):
+                        if "transforms" in config:
+                            for transform_stanza_name in setting.value.replace(
+                                " ", ""
+                            ).split(","):
+                                if not config["transforms"].has_section(
+                                    transform_stanza_name
+                                ):
+                                    yield WarningMessage(
+                                        f"Transforms.conf does not contain a [{transform_stanza_name.strip()}] stanza"
+                                        f"to match props.conf [{section.name}] {setting.name}={setting.value}",
+                                        file_name=config["props"].get_relative_path(),
+                                        line_number=setting.lineno,
+                                        remediation=f"Add a [{transform_stanza_name.strip()}] stanza to transforms.conf"
+                                    )
+                                    return
+                                transforms_section = config["transforms"].get_section(
+                                    transform_stanza_name
+                                )
+                                if transforms_section.has_option("DEST_KEY"):
+                                    dest = transforms_section.get_option("DEST_KEY")
+                                    if dest.value not in allowed_dest_keys:
+                                        yield WarningMessage(
+                                            f"Modifying the {dest.value} field for "
+                                            "a pretrained sourcetype is not allowed.",
+                                            file_name=config[
+                                                "transforms"
+                                            ].get_relative_path(),
+                                            line_number=dest.lineno,
+                                        )
+                        else:
+                            yield WarningMessage(
+                                "No transforms.conf exists for setting in "
+                                f"props.conf: {setting.name}={setting.value}",
+                                file_name=config["props"].get_relative_path(),
+                                line_number=setting.lineno,
                             )
 
 
