@@ -11,6 +11,8 @@ import re
 import semver
 
 import splunk_appinspect
+from splunk_appinspect.checks import Check, CheckConfig
+from splunk_appinspect.check_messages import FailMessage, WarningMessage
 from splunk_appinspect.regex_matcher import RegexBundle, RegexMatcher
 from splunk_appinspect.check_routine.python_ast_searcher.ast_searcher import AstSearcher
 from splunk_appinspect.check_routine.python_ast_searcher.node_filters import (
@@ -87,7 +89,7 @@ def check_for_hidden_python_files(app, reporter):
                     break
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_for_compiled_python(app, reporter):
     """Check that there are no `.pyc` or `.pyo` files included in the app."""
@@ -99,7 +101,7 @@ def check_for_compiled_python(app, reporter):
         reporter.fail(reporter_output, current_file_relative_path)
 
 
-@splunk_appinspect.tags("cloud", "ast", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("cloud", "ast", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_possible_threading(app, reporter):
     """Check for the use of threading, and multiprocesses. Threading or process must be
@@ -238,6 +240,7 @@ def check_for_file_and_directory_access(app, reporter):
     "ast",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.7.0")
@@ -818,6 +821,7 @@ def check_for_internet_protocols_and_support(app, reporter):
     "ast",
     "private_app",
     "private_victoria",
+    "migration_victoria",
     "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.7.0")
@@ -902,6 +906,7 @@ def check_for_debugging_and_profiling(app, reporter):
     files_with_results = AstSearcher(app.python_analyzer_client).search(check_objects)
     reporter.ast_manual_check(message, files_with_results)
 
+
 @splunk_appinspect.tags("splunk_appinspect", "cloud", "security")
 def check_python_httplib2_version(app, reporter):
     """Check python httplib2 version."""
@@ -948,3 +953,70 @@ def check_python_httplib2_version(app, reporter):
         reporter_output = "Python httplib2 library not found."
         reporter.not_applicable(reporter_output)
 
+
+class CheckPythonSdkVersion(Check):
+    def __init__(self):
+        super().__init__(config=CheckConfig(
+            name="check_python_sdk_version",
+            description="Check that Splunk SDK for Python is up-to-date.",
+            cert_min_version="2.11.1",
+            tags=(
+                "cloud", 
+                "private_app", 
+                "private_victoria", 
+                "migration_victoria", 
+                "private_classic", 
+                "future"
+            ),
+        ))
+
+    MINIMUM_SDK_VERSION = semver.VersionInfo.parse("1.6.16")
+    LATEST_SDK_VERSION = semver.VersionInfo.parse("1.7.3")
+
+    @Check.depends_on_matching_files(
+        patterns=[r"\"User-Agent\": \"splunk-sdk-python/([\d.]+.*)\""],
+        names=["binding.py"],
+        not_applicable_message="Splunk SDK for Python not found."
+    )
+    def check_python_sdk(self, app, path_in_app, line_number, result):
+        # Parse the found version into semver, correcting for
+        # bad versions like "0.1" without a patch version
+        ver = result.groups()[0]
+
+        try:
+            if len(ver.split(".")) == 2:
+                ver += ".0"  # correct for versions without a patch
+            parsed_ver = semver.VersionInfo.parse(ver)
+        except Exception as err:
+            yield WarningMessage(
+                "Issue parsing version found in for the Splunk SDK for "
+                f"Python ({ver}). Error: {err}.",
+                file_name=path_in_app,
+                line_number=line_number,
+            )
+            return
+
+        if parsed_ver < self.MINIMUM_SDK_VERSION:
+            # Found splunklib version is less than the minimum
+            yield FailMessage(
+                "Detected an outdated version of the Splunk SDK for "
+                f"Python ({ver}).",
+                file_name=path_in_app,
+                line_number=line_number,
+                remediation=f"Upgrade to {self.LATEST_SDK_VERSION} or later.",
+            )
+        elif self.MINIMUM_SDK_VERSION <= parsed_ver < self.LATEST_SDK_VERSION:
+            yield WarningMessage(
+                "Detected an outdated version of the Splunk SDK for "
+                f"Python ({ver}).",
+                file_name=path_in_app,
+                line_number=line_number,
+                remediation=f"Upgrade to {self.LATEST_SDK_VERSION} or later.",
+            )
+        else:
+            yield WarningMessage(
+                f"Splunk SDK for Python detected (version {ver}).",
+                file_name=path_in_app,
+                line_number=line_number,
+                remediation="No action required at this time.",
+            )
\ No newline at end of file
