@@ -6,6 +6,7 @@ Ensure that the **.spec** files located in the **/README** folder of the app is
 import os
 
 import splunk_appinspect
+from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
 
 
 @splunk_appinspect.tags("spec")
@@ -22,6 +23,9 @@ def check_no_default_or_value_before_stanzas(app, reporter):
     for directory, filename, _ in app.iterate_files(basedir="README", types=[".spec"]):
         file_path = os.path.join(directory, filename)
         spec_file = app.get_spec(filename, directory, None)
+        filename_without_spec = filename.split('.spec')[0]
+        if filename_without_spec not in SPLUNK_DEFINED_CONFS:
+            continue
         # Fail this check if:
         #  1) Contains "default" stanza
         #  2) Have key value pairs before first stanza
