@@ -276,7 +276,7 @@ def _combine_messages_in_special_files(
         messages_in_special_files[file_path] = message
 
 
-@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_sensitive_info_in_url(app, reporter):
     """Check for sensitive information being exposed in transit via URL query string parameters"""
@@ -432,7 +432,7 @@ def check_for_environment_variable_use_in_python(app, reporter):
         reporter.fail(reporter_output, filename, line)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "private_classic")
+@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.2")
 def check_symlink_outside_app(app, reporter):
     """Check no symlink points to the file outside this app"""
@@ -461,7 +461,7 @@ def check_symlink_outside_app(app, reporter):
                     reporter.fail(reporter_output, app_file_path)
 
 
-@splunk_appinspect.tags("cloud", "private_app", "splunk_9_0", "private_victoria", "private_classic", "pura")
+@splunk_appinspect.tags("cloud", "private_app", "splunk_9_0", "private_victoria", "migration_victoria", "private_classic", "pura")
 def check_for_supported_tls(app, reporter):
     """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
     client = app.python_analyzer_client
