@@ -53,6 +53,7 @@ class CheckServerConfOnlyContainsCustomConfSyncStanzasOrDiagStanza(Check):
                 "cloud",
                 "private_app",
                 "private_victoria",
+                "migration_victoria",
                 "private_classic"
             )
         ))
@@ -67,9 +68,10 @@ class CheckServerConfOnlyContainsCustomConfSyncStanzasOrDiagStanza(Check):
             elif server.name == "diag":
                     yield from _check_disallow_settings(file_name, server, "EXCLUDE-.*")
             else:
-                yield FailMessage(f"Stanza `[{server.name}]` configures Splunk server "
-                        "settings and is not permitted in Splunk Cloud. ",
-                        file_name = file_name,
-                        line_number = config["server"][server.name].get_line_number(),
-                        remediation="Please remove this stanza or all of server.conf."
-                    )
+                yield FailMessage(
+                    f"Stanza `[{server.name}]` configures Splunk server settings and is not "
+                    "permitted in Splunk Cloud.",
+                    file_name=file_name,
+                    line_number=config["server"][server.name].get_line_number(),
+                    remediation="Please remove this stanza or all of server.conf."
+                )
