@@ -35,7 +35,7 @@ def check_all_lookups_are_used(app, reporter):
 
     if app.file_exists("default", "transforms.conf"):
         file_path = os.path.join("default", "transforms.conf")
-        transforms = app.transforms_conf()
+        transforms = app.get_config("transforms.conf")
         for section in transforms.sections():
             if section.has_option("filename"):
                 lookup_file_name = section.get_option("filename").value
@@ -58,7 +58,7 @@ def check_capture_groups_in_transforms(app, reporter):
     [non-capture group syntax](http://docs.splunk.com/Documentation/Splunk/latest/Knowledge/AboutSplunkregularexpressions#Non-capturing_group_matching)
     """
     if app.file_exists("default", "transforms.conf"):
-        transforms = app.transforms_conf()
+        transforms = app.get_config("transforms.conf")
         file_path = os.path.join("default", "transforms.conf")
         for section in transforms.sections():
             if section.has_option("REGEX") and section.has_option("FORMAT"):
