@@ -18,7 +18,7 @@ report_display_order = 7
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "private_app", "private_victoria", "private_classic"
+    "splunk_appinspect", "appapproval", "cloud", "private_app", "private_victoria", "migration_victoria", "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_that_all_xml_files_are_well_formed(app, reporter):
