@@ -146,6 +146,10 @@ class MergedConfigurationSection(object):
     def name(self):
         return self.sections[-1].name
 
+    @property
+    def lineno(self):
+        return self.get_line_number()
+
     @property
     def options(self):
         return {optname: self.get_option(optname) for optname in self.settings_names()}
@@ -183,7 +187,7 @@ class ConfigurationFile(object):
     def get(self, sectionname, key):
         if self.has_section(sectionname):
             option = self.sects[sectionname].get_option(key)
-            if option is not None:
+            if isinstance(option, ConfigurationSetting):
                 return option.value
 
             error_output = (
@@ -279,7 +283,9 @@ class MergedConfigurationFile:
 
         for config in self.configs:
             if config.has_option(sectionname, key):
-                return config.get_option(sectionname, key)
+                option = config.get_option(sectionname, key)
+                if isinstance(option, ConfigurationSetting):
+                    return option.value
 
         error_output = (
             "The option does not exist in the section "
@@ -310,6 +316,14 @@ class MergedConfigurationFile:
             return section_configs[0]
 
         return MergedConfigurationSection(*section_configs)
+    
+    def get_option(self, sectionname, option):
+        for config in self.configs:
+            if config.has_option(sectionname, option):
+                return config.get_option(sectionname, option)
+            
+        error_output = f"No option '{option}' exists in section '{sectionname}'"
+        raise NoOptionError(error_output)
 
     def section_names(self):
         touched = []
@@ -343,6 +357,17 @@ class MergedConfigurationFile:
 
     def __getitem__(self, sectionname):
         return self.get_section(sectionname)
+    
+    def __bool__(self):
+        """
+        Return False when there are no underlying configs, to make logic like this work:
+        
+        conf_file = app.merged_config["server"]
+        if not (conf_file and conf_file.has_section("foo")):
+            return
+        """
+
+        return len(self.configs) > 0
 
 
 class ConfigurationProxy:
@@ -358,10 +383,13 @@ class ConfigurationProxy:
         self.configs = {}
 
     def __getitem__(self, conf_file_name):
-        """Get a configuration file, loading it from the app if needed
+        """Get a configuration file, loading it from the app if needed.
 
         Returns:
-            ConfigurationFile instance"""
+            ConfigurationFile instance or None if it does not exist"""
+        if not self.__contains__(conf_file_name):
+            return None
+
         if not conf_file_name.endswith(".conf"):
             conf_file_name = f"{conf_file_name}.conf"
 
