@@ -4,7 +4,6 @@ import re
 
 import splunk_appinspect
 
-from . import commands_configuration_file
 from .file_resource import FileResource
 
 # http://docs.splunk.com/Documentation/Splunk/7.2.0/Search/Customcommandlocation#Platform-specific_custom_commands
@@ -76,8 +75,7 @@ class CustomCommands:
 
     Attributes:
         app (App Object): The app object that represents a Splunk app.
-        commands_conf_file_path (String): The path to where the commands
-            conf file exists.
+        config (ConfigurationProxy|MergedConfigurationProxy): a set of configuration to be checked
         V1_EXE_TAG (String): A string used to tag a FileResource
             object with its respective custom command location
         WINDOWS_EXE_TAG (String): A string used to tag a FileResource
@@ -95,9 +93,9 @@ class CustomCommands:
             command in a linux environment
     """
 
-    def __init__(self, app):
+    def __init__(self, app, config=None):
         self.app = app
-        self.commands_conf_file_path = app.get_filename("default", "commands.conf")
+        self.config = config
 
         # architecture stuff
         self.V1_EXE_TAG = "v1_exe"
@@ -110,13 +108,14 @@ class CustomCommands:
         self.ALL_VALID_EXES = list(set(self.WINDOWS_EXES) | set(self.NIX_EXES))
 
     def configuration_file_exists(self):
+        if self.config is not None: # class based checks
+            return "commands" in self.config
         return self.app.file_exists("default", "commands.conf")
 
     def get_configuration_file(self):
-        return self.app.get_config(
-            "commands.conf",
-            config_file=commands_configuration_file.CommandsConfigurationFile(),
-        )
+        if self.config is not None: # class based checks
+            return self.config["commands"]
+        return self.app.get_config("commands.conf")
 
     def find_pointer_scripts(self, pointer_file):
         pointer_scripts = []
@@ -215,8 +214,6 @@ class CustomCommands:
                 case-sensitve
         """
 
-        # command_list = []
-
         for section in self.get_configuration_file().sections():
 
             command = Command(section)
@@ -312,6 +309,5 @@ class CustomCommands:
             )
 
             command.executable_files = list(files)
-            # command_list.append(command)
 
             yield command
