@@ -59,10 +59,10 @@ class InspectedFile(object):
         # In general text file, no need to remove comments
         return content
 
-    def search_for_patterns(self, patterns, excluded_comments=True, regex_option=0):
+    def search_for_patterns(self, patterns, exclude_comments=True, regex_option=0):
         """
         :param patterns: regex patterns array
-        :param excluded_comments: excluded comment from test
+        :param exclude_comments: excluded comment from test
         :param regex_option: regex option
         :return: array of match objects
         """
@@ -74,7 +74,7 @@ class InspectedFile(object):
         content = inspected_file.read()
         inspected_file.close()
 
-        if excluded_comments:
+        if exclude_comments:
             content = self._remove_comments(content)
         for line in content.splitlines():
             line_no += 1
@@ -85,16 +85,16 @@ class InspectedFile(object):
 
         return matches
 
-    def search_for_pattern(self, pattern, excluded_comments=True, regex_option=0):
+    def search_for_pattern(self, pattern, exclude_comments=True, regex_option=0):
         """Same with search_for_patterns except single pattern."""
-        return self.search_for_patterns([pattern], excluded_comments, regex_option)
+        return self.search_for_patterns([pattern], exclude_comments, regex_option)
 
     def search_for_crossline_patterns(
-        self, patterns, excluded_comments=True, cross_line=10
+        self, patterns, exclude_comments=True, cross_line=10
     ):
         """
         :param patterns: regex patterns array
-        :param excluded_comments: excluded comment from test
+        :param exclude_comments: excluded comment from test
         :return: array of match objects
         """
 
@@ -104,7 +104,7 @@ class InspectedFile(object):
         content = inspected_file.read()
         inspected_file.close()
 
-        if excluded_comments:
+        if exclude_comments:
             content = self._remove_comments(content)
 
         lines_content = content.splitlines()
@@ -129,12 +129,12 @@ class InspectedFile(object):
         return matches
 
     def search_for_crossline_pattern(
-        self, pattern, excluded_comments=True, cross_line=10
+        self, pattern, exclude_comments=True, cross_line=10
     ):
         """Same with search_for_crossline_patterns except single pattern."""
         return self.search_for_crossline_patterns(
             patterns=[pattern],
-            excluded_comments=excluded_comments,
+            exclude_comments=exclude_comments,
             cross_line=cross_line,
         )
 
