@@ -8,5 +8,5 @@ from . import configuration_file
 class OutputsConfigurationFile(configuration_file.ConfigurationFile):
     """Represents an `outputs.conf` file."""
 
-    def __init__(self):
-        configuration_file.ConfigurationFile.__init__(self)
+    def __init__(self, name=None):
+        configuration_file.ConfigurationFile.__init__(self,name=name)
