@@ -1,5 +1,7 @@
-from splunk_appinspect.python_analyzer.trustedlibs import trusted_data_collector
-from splunk_appinspect.python_analyzer.trustedlibs import utilities
+from splunk_appinspect.python_analyzer.trustedlibs import (
+    trusted_data_collector,
+    utilities,
+)
 
 
 class TrustedLibsManager(object):
