@@ -8,8 +8,6 @@ as needed.
 import concurrent.futures
 import logging
 
-from futures_then import ThenableFuture
-
 import splunk_appinspect
 from splunk_appinspect.checks import Group
 from splunk_appinspect.python_analyzer.trustedlibs.trusted_libs_manager import (
@@ -317,12 +315,7 @@ class Validator(object):
         self.__emit_event("finish_check", self.listeners, check, reporter)
         return reporter
 
-    def __dispatch_check(self, ready_for_deferred, threadpool, context, app, check):
-        if check.deferred:
-            return ready_for_deferred.then(
-                lambda _: threadpool.submit(self.__execute_check, context, app, check)
-            )
-
+    def __dispatch_check(self, threadpool, context, app, check):
         return threadpool.submit(self.__execute_check, context, app, check)
 
     def __skip_checks(self, groups):
@@ -352,8 +345,6 @@ class Validator(object):
         """
         futures = []
         with concurrent.futures.ThreadPoolExecutor(max_workers=1) as threadpool:
-            ready_for_deferred = ThenableFuture()
-
             logger.debug("Beginning validation execution.")
             for group in groups:
                 logger.debug(
@@ -377,13 +368,13 @@ class Validator(object):
                         lambda check: (
                             check,
                             self.__dispatch_check(
-                                ready_for_deferred, threadpool, context, app, check
+                                threadpool, context, app, check
                             ),
                         ),
                         group.checks(),
                     )
                 )
-                # This accumulates the deferred checks
+                # This accumulates the called checks
                 futures.append((group, future_checks))
                 self.__emit_event(
                     "finish_dispatching_group", self.listeners, group, group.checks()
@@ -401,9 +392,6 @@ class Validator(object):
                     self.listeners,
                 )
 
-            # This allows the deferred checks to be run
-            ready_for_deferred.set_result(True)
-
         # After exiting 'with', all checks are run.
         # future.result() calls a promise that returns the reporter
         return_values = []
